/*
 * USB Shim layer driver    
 *
 * Copyright (C) 2010, Broadcom Corporation
 * All Rights Reserved.
 * 
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Broadcom Corporation;
 * the contents of this file may not be disclosed to third parties, copied
 * or duplicated in any form, in whole or in part, without the prior
 * written permission of Broadcom Corporation.
 *
 * $Id: bcm_usbshim.c,v 1.2.2.2 2010/04/27 23:45:40 Exp $
 */

#include <linux/init.h>
#include <linux/module.h>
#include <linux/kernel.h>
#include <linux/version.h>
#include <bcm_usbshim.h>

MODULE_LICENSE("GPL");

struct urb * bcm_usb_alloc_urb(int iso_pkts)
{
	return usb_alloc_urb(iso_pkts, GFP_ATOMIC);
}

int bcm_usb_submit_urb(struct urb *urb)
{
	return usb_submit_urb(urb, GFP_ATOMIC);
}

void bcm_usb_kill_urb(struct urb *urb)
{
	usb_kill_urb(urb);
}

void bcm_usb_free_urb(struct urb *urb)
{
	usb_free_urb(urb);
}

void bcm_usb_register(struct usb_driver * usbdev)
{
	usb_register(usbdev);
}

void bcm_usb_deregister(struct usb_driver * usbdev)
{
	usb_deregister(usbdev);
}

int bcm_autopm_set_interface(struct usb_interface *intf)
{
#if ((LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 21)) && defined(CONFIG_USB_SUSPEND))
	return usb_autopm_set_interface(intf);
#else
	return 0;
#endif /* ((LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 21)) && defined(CONFIG_USB_SUSPEND)) */
}

const struct s_usburb bcm_usburb = {
	.bcm_alloc_urb    = bcm_usb_alloc_urb,
	.bcm_free_urb     = bcm_usb_free_urb,
	.bcm_kill_urb     = bcm_usb_kill_urb,
	.bcm_submit_urb   = bcm_usb_submit_urb,
	.bcm_register     = bcm_usb_register,
	.bcm_deregister   = bcm_usb_deregister,
	.bcm_autopm_set_interface   = bcm_autopm_set_interface,
};
EXPORT_SYMBOL(bcm_usburb);

static int usbshim_module_init(void) { return 0; }
static void usbshim_module_exit(void) { }

module_init(usbshim_module_init);
module_exit(usbshim_module_exit);
